﻿/******************************************************************************
 * 文件名称: CenterBusiness.cs
 * 文件说明: 中心交易封装
 * 当前版本: V1.0
 * 创建日期: 2022-06-20
 *
 * * 2020-06-20: 增加 CenterBusiness 类
 * *****  2020-06-20: 增加 CardReader 方法，获取URL地址,USER信息，地方版SSCard.dll使用
 * *****  2020-06-20: 增加 CardReader 方法重载，国家版电子凭证使用
 * *****  2020-06-20: 增加 Init 方法，SSCard环境初始化



******************************************************************************/
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json.Linq;
using PTMedicalInsurance.Common;
using PTMedicalInsurance.Helper;
using PTMedicalInsurance.Variables;

namespace PTMedicalInsurance.Business
{

   
    class CenterBusiness
    {
        private InvokeHelper invoker = new InvokeHelper();

        #region 目录下载
        /// <summary>
        /// 下载业务（1301-1309），返回会的JSON串中包含解压后的TXT地址
        /// </summary>
        /// <param name="funNO"></param>
        /// <param name="ver"></param>
        /// <param name="outPath"></param>
        /// <returns></returns>
        public JObject DownDictionay(JObject joData)
        {
            string outparam = "";
            try
            {
                dynamic joParam = new JObject();
                joParam.data = joData;
                JObject joRtn = invoker.invokeCenterService("1901", joParam);
                outparam = joRtn.ToString();
                return joRtn;
            }
            catch (Exception ex)
            {
                JObject joRtn = JsonHelper.setExceptionJson(-1, "DownDictionay:", ex.Message);
                outparam = joRtn.ToString();
                return joRtn;
            }
        }

        /// <summary>
        /// 下载业务（1301-1309），返回会的JSON串中包含解压后的TXT地址
        /// </summary>
        /// <param name="funNO"></param>
        /// <param name="ver"></param>
        /// <param name="outPath"></param>
        /// <returns></returns>
        public JObject DownDirecotry(string funNO, string ver)
        {
            try
            {
                dynamic joTmp = new JObject();
                joTmp.ver = ver;
                JObject joData = new JObject {
                    { "data",joTmp}
                };

                return invoker.invokeCenterService(funNO, joData);
            }
            catch (Exception ex)
            {
                return JsonHelper.setExceptionJson(-1, "DownDirecotry:", ex.Message);
            }
        }

        /// <summary>
        /// 91021保存文件
        /// </summary>
        /// <param name="jo"></param>
        /// <returns>正常返回结果同中心文档，异常返回结果同HIS</returns>

        public JObject SaveFile(JObject jo)
        {
            try
            {
                string filename = JsonHelper.getDestValue(jo, "output.filename");
                string file_qury_no = JsonHelper.getDestValue(jo, "output.file_qury_no");
                string data_cnt = JsonHelper.getDestValue(jo, "output.data_cnt");

                dynamic jo9102InParam = new JObject();
                dynamic jofsDownloadIn = new JObject();
                jofsDownloadIn.filename = filename;
                jofsDownloadIn.file_qury_no = file_qury_no;
                jofsDownloadIn.fixmedins_code = Global.inf.hospitalNO;
                jo9102InParam.fsDownloadIn = jofsDownloadIn;
                return  invoker.DownloadCenterFile(filename,JsonHelper.setCenterInpar("9102", jo9102InParam.ToString()));

            }
            catch (Exception ex)
            {
                return JsonHelper.setExceptionJson(-1, "9102保存文件", ex.Message);
            }
        }
        #endregion

        /// <summary>
        /// 签到
        /// </summary>
        /// <returns></returns>
        public int signIn(out JObject joRtn)
        {
            string outParam = "";
            string inParam = "";
            try
            {
                dynamic jsonSignIn = new JObject();
                dynamic jsonInput = new JObject();
                jsonSignIn.opter_no = Global.user.ID;
                jsonSignIn.mac = Global.curEvt.mac;
                jsonSignIn.ip = Global.curEvt.ip;
                jsonInput.signin = jsonSignIn;
                outParam = invoker.invokeCenterService("9001", jsonInput).ToString();
                joRtn = JObject.Parse(outParam);
                if (joRtn["infcode"].ToString() == "0")
                {
                    Global.curEvt.signno = joRtn["output"]["signinoutb"]["sign_no"].ToString();
                    return 0;
                }
                else
                {
                    //joRtn = JsonHelper.getIrisExceptionJson(-100, "签到异常", (string)joRtn["err_msg"]);
                    Global.curEvt.signno = "";
                    return -1;
                }

            }
            catch (Exception ex)
            {
                joRtn = new JObject();
                joRtn.Add("infcode", -1);
                joRtn.Add("err_msg", outParam + ex.Message);
                //joRtn = JsonHelper.getIrisExceptionJson(-100,"签到异常", outParam + ex.Message);
                return -2;
            }

        }


        public int Authenticate(out string outPar)
        {
            outPar = "";
            try
            {
                JObject joData = new JObject();
                joData.Add("mdtrt_cert_type", Global.pat.mdtrtcertType);
                joData.Add("card_sn", Global.pat.card.SN);
                joData.Add("card_pwd", Global.pat.card.password);
                joData.Add("psn_cert_type", Global.pat.certType);
                joData.Add("certno", Global.pat.card.NO);
                joData.Add("real_certno", Global.pat.certNO);
                joData.Add("card_lv", Global.pat.card.level);
                joData.Add("psn_name", Global.pat.name);
                joData.Add("extra", "");
                JObject joInput = new JObject();
                joInput.Add("data",joData);
                string funNO = "1160";
                JObject joRtn = invoker.invokeCenterService(funNO, joInput);
                string errMsg;
                if (JsonHelper.parseCenterRtnValue(joRtn,out errMsg) != 0)
                {
                    outPar = errMsg;
                    return -1;
                }
                else
                {
                    outPar = joRtn.ToString();
                    return 0;
                }
               
            }
            catch (Exception ex)
            {
                return -1;
            }
        }
        //就医特殊属性上传
        public int UploadAdmSpecAttribute(out string outPar)
        {
            outPar = "";
            if (string.IsNullOrEmpty(Global.pat.specAttribute))
            {
                outPar = "患者就医特殊属性(specAttribute)为空！";
                return -1;
            }
            try
            {
                JObject joData = new JObject();
                joData.Add("mdtrt_id", Global.pat.mdtrtID);
                joData.Add("psn_no", Global.pat.psn_no);
                joData.Add("psn_cert_type", Global.pat.certType);
                joData.Add("certno", Global.pat.certNO);
                joData.Add("psn_name", Global.pat.name);
                joData.Add("ipt_otp_no", Global.pat.adm_Dr);
                joData.Add("ipt_psn_sp_flag_type", Global.pat.specAttribute);
                joData.Add("ipt_psn_sp_flag", 1);
                joData.Add("memo", "");
                joData.Add("admdvs", Global.pat.insuplc_admdvs);
                JObject joInput = new JObject();
                joInput.Add("IptPsnSpFlagRegIn", joData);
                string funNO = "2406";
                JObject joRtn = invoker.invokeCenterService(funNO, joInput);
                string errMsg;
                if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                {
                    outPar = errMsg;
                    return -1;
                }
                else
                {
                    outPar = joRtn.ToString();
                    return 0;
                }

            }
            catch (Exception ex)
            {
                outPar = "上传就医属性异常：" + ex.Message;
                return -1;
            }
        }

        /// <summary>
        /// 住院患者登记
        /// </summary>
        /// <returns></returns>
        public int inPatReg(string inParam,out string outparam)
        {
            outparam = "";
            try
            {

                return 0;
            }
            catch (Exception ex)
            {
                return -1;
            }
        }


        public int cancleRegister(string funNO, out string outparam)
        {
            outparam = "";
            string errMsg;
            try
            {
                dynamic joTmp = new JObject();
                joTmp.mdtrt_id = Global.pat.mdtrtID;
                joTmp.psn_no = Global.pat.psn_no;
                if (funNO == "2202")
                {
                    joTmp.ipt_otp_no = Global.pat.adm_Dr.ToString();
                }
                JObject joData = new JObject();
                joData.Add("data", joTmp);
                //好后上传给中心
                //string inpar = GlobalVariables.SetJsonParam("2405", joTmp).ToString();

                JObject joRtn = invoker.invokeCenterService(funNO, joData);
                if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                {
                    outparam = errMsg;
                    return -1;
                }
                else
                {
                    outparam = joRtn.ToString();
                    return 0;
                }
            }
            catch (Exception ex)
            {
                outparam = "取消登记异常" + funNO + ":" + ex.Message;
                return -1;
            }
        }

        /// <summary>
        /// 取消费用传送
        /// </summary>
        /// <param name="pat"></param>
        /// <param name="errMsg"></param>
        /// <returns></returns>
        public int cancleFeeUpload(string funNO,out string errMsg)
        {
            errMsg = "";
            try
            {
                //组织入参
                dynamic joTmp = new JObject();
                if (funNO == "2205")
                {
                    joTmp.chrg_bchno = "0000";
                }
                else
                {
                    joTmp.feedetl_sn = "0000";
                }
                
                joTmp.mdtrt_id = Global.pat.mdtrtID;
                joTmp.psn_no = Global.pat.psn_no;
                joTmp.expContent = "";
                JObject joData = new JObject();
                if (funNO == "2205")
                {
                    joData.Add("data", joTmp);
                }
                else
                {
                    JArray jaData = new JArray();
                    jaData.Add(joTmp);
                    joData.Add("data", jaData);
                }
                    

                //组织好后上传给中心
                JObject joRtn = invoker.invokeCenterService(funNO, joData);
                if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                {
                    return -1;
                }
                else
                {
                    return 0;
                }
            }
            catch (Exception ex)
            {
                errMsg = "cancleFeeUpload异常：" + ex.Message;
                return -1;
            }
        }

        public int cancleSettlement(string funNO, out string outparam)
        {
            outparam = "";
            string errMsg;
            try
            {
                dynamic joTmp = new JObject();
                joTmp.mdtrt_id = Global.pat.mdtrtID;
                joTmp.psn_no = Global.pat.psn_no;
                joTmp.setl_id = Global.pat.settlID;
                joTmp.expContent = "";
                JObject joData = new JObject();
                joData.Add("data", joTmp);
                JObject joRtn = invoker.invokeCenterService(funNO, joData);
                if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                {
                    outparam = errMsg;
                    return -1;
                }
                else
                {
                    outparam = joRtn.ToString();
                    return 0;
                }
            }
            catch (Exception ex)
            {
                outparam = "取消结算异常" + funNO + ":" + ex.Message;
                return -1;
            }
        }

        public int UpdateDirectory_HEB(JObject joData, out string outparam)
        {
            outparam = "";
            string funNO = "";
            string errMsg;
            try
            {
                string type = JsonHelper.getDestValue(joData,"type");
                funNO = "136" + type;//1360 西药 1361中草药 1362 自制剂 1363 民族药药品 1364 耗材 1365 诊疗
                joData.Remove("type");
                JObject joInput = new JObject();
                joInput.Add("data", joData);

                JObject joRtn = invoker.invokeCenterService(funNO, joInput);
                if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                {
                    outparam = errMsg;
                    return -1;
                }
                else
                {
                    outparam = joRtn.ToString();
                    return 0;
                }
            }
            catch (Exception ex)
            {
                outparam = "查询中心目录算异常" + funNO + ":" + ex.Message;
                return -1;
            }
        }
    }
}
