﻿using Newtonsoft.Json.Linq;
using PTMedicalInsurance.Common;
using PTMedicalInsurance.Helper;
using PTMedicalInsurance.Variables;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace PTMedicalInsurance.Business
{
    class PreAndInProcessAnalysis
    {
        private HisIrisServices hIS = new HisIrisServices();

        private JArray patient_dtos; //患者信息集合
        private JArray fsi_encounter_dtos; //就诊信息集合
        private JArray fsi_diagnose_dtos;  //诊断信息集合
        private JArray fsi_order_dtos; //处方信息集合
        private JArray fsi_operation_dtos; // 手术信息集合

        MIIrisServices mis = new MIIrisServices();
        public PreAndInProcessAnalysis(string inpar)
        {
            try
            {
                JObject jo = JObject.Parse(inpar);
                JObject joResult = JObject.FromObject(jo["result"]);
                patient_dtos = JArray.FromObject(joResult["patient_dtos"]);

                fsi_encounter_dtos = JArray.FromObject(patient_dtos[0]["fsi_encounter_dtos"]);
                fsi_diagnose_dtos = JArray.FromObject(fsi_encounter_dtos[0]["fsi_diagnose_dtos"]);
                fsi_order_dtos = JArray.FromObject(fsi_encounter_dtos[0]["fsi_order_dtos"]);
                fsi_operation_dtos = JArray.FromObject(fsi_encounter_dtos[0]["fsi_operation_dtos"]);
            }
            catch (Exception ex)
            {
                Global.writeLog("PreAndInProcessAnalysis构造异常：" + ex.Message);
                throw;
            }
        }
        #region 设置Patient
        public int setPatientByHisBaseInfo(out string msg)
        {
            string errMsg = string.Empty;
            msg = "";
            try
            {
                if (hIS.GetHisPatBaseInfo(out errMsg) != 0)
                {
                    msg = errMsg;
                    return -1;
                }
                JObject jo = JObject.Parse(errMsg);
                Global.pat.name = JsonHelper.getDestValue(jo, "result.patName");
                Global.pat.brdy = JsonHelper.getDestValue(jo, "result.patBirthdate");
                Global.pat.gend = JsonHelper.getDestValue(jo, "result.patSex");
                Global.pat.age = JsonHelper.getDestValue(jo, "result.Age");
                Global.pat.naty = JsonHelper.getDestValue(jo, "result.naty");
                Global.pat.certNO = JsonHelper.getDestValue(jo, "result.credNo");
                Global.pat.certType = JsonHelper.getDestValue(jo, "result.credCode");
                return 0;
            }
            catch (Exception ex)
            {
                msg = ex.Message;
                return -1;
            }
        }

        #endregion

        public JObject Get3101Inpar(string trig_scen,Patients p)
        {
            try
            {
                JObject joInpar = new JObject();
                joInpar.Add("syscode", "YBJK");
                joInpar.Add("patientDtos", GetPatient_dtos(trig_scen, p)[0]);
                joInpar.Add("rule_ids", null);
                joInpar.Add("task_id", GetMsgID());
                joInpar.Add("trigScen", trig_scen);
                JObject joData = new JObject();
                joData.Add("data",joInpar);
                return joData;
            }
            catch (Exception ex)
            {
                MessageBox.Show("Get3101Inpar:" + ex.Message);
                return null;
            }
        }

        private string GetMsgID()
        {
            return Global.inf.hospitalNO + DateTime.Now.ToString("yyyyMMddHHmmssffff");
        }

        public JArray GetPatient_dtos(string trig_scen, Patients p)
        {
            try
            {
                string curr_mdtrt_id = p.mdtrtID;
                if (string.IsNullOrEmpty(curr_mdtrt_id))
                {
                    curr_mdtrt_id = Global.pat.adm_Dr.ToString();
                }
                JObject joInpar = new JObject();
                joInpar.Add("patnId", p.psn_no);
                joInpar.Add("patnName", p.name);
                string gend = p.gend;
                if (gend == "男") gend = "1";
                if (gend == "女") gend = "2";
                joInpar.Add("gend",gend);
                joInpar.Add("brdy", p.brdy);
                if (p.insuplc_admdvs == "") p.insuplc_admdvs = Global.pat.insuplc_admdvs;
                joInpar.Add("poolarea", p.insuplc_admdvs);
                joInpar.Add("curr_mdtrt_id", curr_mdtrt_id);
                joInpar.Add("encounterDtos", GetFsi_encounter_dtos(trig_scen,p)[0]);
                joInpar.Add("fsi_his_data_dto", new JArray());
                JArray ja = new JArray();
                ja.Add(joInpar);
                return ja;
            }
            catch (Exception ex)
            {
                MessageBox.Show("GetPatient_dtos:" + ex.Message);
                return null;
            }
        }

        public JArray GetFsi_encounter_dtos(string trig_scen, Patients p)
        {
            try
            {
                JObject jofsi_encounter_dtos = JObject.FromObject(fsi_encounter_dtos[0]);
                JObject joInpar = new JObject(); 
                string mdtrtID = p.mdtrtID;
                if (string.IsNullOrEmpty(mdtrtID)) mdtrtID = Global.pat.adm_Dr.ToString();
                joInpar.Add("mdtrtId", mdtrtID);  //就诊标识
                joInpar.Add("medinsId", Global.inf.hospitalNO);  //医疗服务机构标识
                joInpar.Add("medinsName", Global.inf.hospitalName);  //医疗机构名称
                joInpar.Add("medinsAdmdvs", Global.inf.areaCode);  //医疗机构行政区划编码
                joInpar.Add("medinsType", "A512");  //医疗服务机构类型
                joInpar.Add("medinsLv", "04");  //医疗机构等级
                joInpar.Add("wardareaCodg", JsonHelper.getDestValue(jofsi_encounter_dtos, "wardarea_codg"));  //病区标识
                joInpar.Add("wardno", JsonHelper.getDestValue(jofsi_encounter_dtos, "wardno"));  //病房号
                joInpar.Add("bedno", JsonHelper.getDestValue(jofsi_encounter_dtos, "bedno"));  //病床号
                joInpar.Add("admDate", JsonHelper.getDestValue(jofsi_encounter_dtos, "adm_date"));  //入院日期
                joInpar.Add("dscgDate", JsonHelper.getDestValue(jofsi_encounter_dtos, "dscg_date"));  //出院日期
                joInpar.Add("dscgMainDiseCodg", JsonHelper.getDestValue(jofsi_encounter_dtos, "dscg_main_dise_codg"));  //主诊断编码
                joInpar.Add("dscgMainDiseName", JsonHelper.getDestValue(jofsi_encounter_dtos, "dscg_main_dise_name"));  //主诊断名称
                joInpar.Add("diagnoseDtos", GetFsi_diagnose__dtos(trig_scen, p));  //诊断信息DTO
                joInpar.Add("drCodg", JsonHelper.getDestValue(jofsi_encounter_dtos, "dr_codg"));  //医师标识
                joInpar.Add("admDeptCodg", JsonHelper.getDestValue(jofsi_encounter_dtos, "adm_dept_codg"));  //入院科室标识
                joInpar.Add("admDeptName", JsonHelper.getDestValue(jofsi_encounter_dtos, "adm_dept_name"));  //入院科室名称
                joInpar.Add("dscgDeptCodg", JsonHelper.getDestValue(jofsi_encounter_dtos, "dscg_dept_codg"));  //出院科室标识
                joInpar.Add("dscgDeptName", JsonHelper.getDestValue(jofsi_encounter_dtos, "dscg_dept_name"));  //出院科室名称
                joInpar.Add("medMdtrtType", JsonHelper.getDestValue(jofsi_encounter_dtos, "med_mdtrt_type"));  //就诊类型
                string med_type = JsonHelper.getDestValue(jofsi_encounter_dtos, "med_type");
                if (string.IsNullOrEmpty(med_type))
                {
                    med_type = Global.pat.medType;
                }
                joInpar.Add("medType", med_type);  //医疗类别
                joInpar.Add("orderDtos", GetFsi__order_dtos(trig_scen,p));  //处方(医嘱)信息
                string matn_stas = JsonHelper.getDestValue(jofsi_encounter_dtos, "matn_stas");
                if (string.IsNullOrEmpty(matn_stas)) matn_stas = "0";
                joInpar.Add("matnStas", matn_stas );  //生育状态
                joInpar.Add("medfeeSumamt", JsonHelper.getDestValue(jofsi_encounter_dtos, "medfee_sumamt"));  //总费用
                joInpar.Add("ownpayAmt", JsonHelper.getDestValue(jofsi_encounter_dtos, "ownpay_amt"));  //自费金额
                joInpar.Add("selfpayAmt", JsonHelper.getDestValue(jofsi_encounter_dtos, "selfpay_amt"));  //自付金额
                joInpar.Add("acctPayamt", JsonHelper.getDestValue(jofsi_encounter_dtos, "acct_payamt"));  //个人账户支付金额
                joInpar.Add("maAmt", JsonHelper.getDestValue(jofsi_encounter_dtos, "ma_amt"));  //救助金支付金额
                joInpar.Add("hifpPayamt", JsonHelper.getDestValue(jofsi_encounter_dtos, "hifp_payamt"));  //统筹金支付金额
                joInpar.Add("setlTotlnum", JsonHelper.getDestValue(jofsi_encounter_dtos, "setl_totlnum"));  //结算总次数
                string insutype = JsonHelper.getDestValue(jofsi_encounter_dtos, "insutype");
                if (insutype =="") insutype = Global.pat.insuType;
                joInpar.Add("insutype", insutype);  //险种
                string reimFlag = JsonHelper.getDestValue(jofsi_encounter_dtos, "reim_flag");
                // 报销标志(必填）
                if (string.IsNullOrEmpty(reimFlag))
                {
                    reimFlag = "1";
                }
                joInpar.Add("reimFlag", reimFlag);
                // 异地结算标志(必填）
                string outSetlFlag = JsonHelper.getDestValue(jofsi_encounter_dtos, "out_setl_flag");
                if (string.IsNullOrEmpty(outSetlFlag))
                {
                    outSetlFlag = Utils.isOtherCityPatient()?"1":"0";
                }
                joInpar.Add("outSetlFlag", outSetlFlag);
                joInpar.Add("fsi_operation_dtos", GetFsi__operation__dtos(trig_scen,p));  //手术操作集合

                JArray ja = new JArray();
                ja.Add(joInpar);
                return ja; 
            }
            catch (Exception ex)
            {
                MessageBox.Show("GetPatient_dtos:" + ex.Message);
                return null;
            }
        }
        public JArray GetFsi_diagnose__dtos(string trig_scen, Patients p)
        {
            try
            {

                JArray diagnose3101=new JArray();

                for (int i = 0; i < fsi_diagnose_dtos.Count; i++)
                {
                    JObject joDls= new  JObject();
                    joDls.Add("diseId", fsi_diagnose_dtos[i]["dise_id"]);
                    joDls.Add("maindiseFlag", fsi_diagnose_dtos[i]["maindise_flag"]);
                    joDls.Add("diasSrtNo", fsi_diagnose_dtos[i]["dias_srt_no"]);
                    joDls.Add("diseDate", fsi_diagnose_dtos[i]["dise_date"]);
                    joDls.Add("diseCodg", fsi_diagnose_dtos[i]["dise_codg"]);
                    joDls.Add("diseName", fsi_diagnose_dtos[i]["dise_name"]);
                    joDls.Add("inoutDiseType", fsi_diagnose_dtos[i]["inout_dise_type"]);
                    diagnose3101.Add( joDls );
                }
                // return fsi_diagnose_dtos;
                return diagnose3101;
            }
            catch (Exception ex)
            {
                MessageBox.Show("GetPatient_dtos:" + ex.Message);
                return null;
            }
        }
        

        public JArray GetFsi__operation__dtos(string trig_scen, Patients p)
        {
            try
            {
                return fsi_operation_dtos;
            }
            catch (Exception ex)
            {
                MessageBox.Show("GetPatient_dtos:" + ex.Message);
                return null;
            }
        }

        #region 组织入参
        public JArray GetFsi__order_dtos(string trig_scen, Patients p)
        {
            string errMsg = "";
            try
            {
                JArray order3101 = new JArray();
                for (int i = 0; i < fsi_order_dtos.Count; i++)
                {
                    decimal pric = decimal.Parse(fsi_order_dtos[i]["pric"].ToString());
                    fsi_order_dtos[i]["pric"] = pric.ToString("#0.00");
                    fsi_order_dtos[i]["hilist_pric"] = pric.ToString("#0.00");

                }


                

                //调用医保平台进行转换
                if (mis.convertFsiOrderDtos(fsi_order_dtos, out errMsg) != 0)
                {
                    return null;
                }
                else
                {
                    JObject joRtn = JObject.Parse(errMsg);

                    JArray joRtn2 = JArray.FromObject(joRtn["data"]);
                    for (int i = 0; i < joRtn2.Count; i++)
                    {
                        JObject joOrls = new JObject();
                        joOrls.Add("lv3HospItemPric", joRtn2[i]["lv3_hosp_item_pric"]);
                        decimal hilistPrc= decimal.Parse(fsi_order_dtos[i]["hilist_pric"].ToString());
                        if (string.IsNullOrEmpty(fsi_order_dtos[i]["hilist_pric"].ToString())) {
                            
                             hilistPrc = 999999 ;
                        } //医保目录价格为空时默认999999 因为部分诊疗无限价，耗材无限价                        
                        fsi_order_dtos[i]["hilistPrc"] = hilistPrc.ToString("#0.00");                        
                        joOrls.Add("hilistPrc", joRtn2[i]["hilist_pric"]);
                        joOrls.Add("hilist_pric", joRtn2[i]["hilist_pric"]);
                        joOrls.Add("specUnt", joRtn2[i]["spec_unt"]);
                        joOrls.Add("drordBhvr", joRtn2[i]["drord_bhvr"]);
                        joOrls.Add("drordDrCodg", joRtn2[i]["drord_dr_codg"]);
                        if (string.IsNullOrEmpty(fsi_order_dtos[i]["chrg_type"].ToString()))
                        {
                            joOrls.Add("chrgType", "14");
                        }
                        else
                        {
                            joOrls.Add("chrgType", joRtn2[i]["chrg_type"]);
                        }                      
                        
                        joOrls.Add("drordDeptName", joRtn2[i]["drord_dept_name"]);
                        joOrls.Add("drordDrName", joRtn2[i]["drord_dr_name"]);
                        if (string.IsNullOrEmpty(fsi_order_dtos[i]["spec"].ToString()))
                        {
                            joOrls.Add("spec", "无");
                        }else
                        {
                            joOrls.Add("spec", joRtn2[i]["spec"]);
                        }
                        joOrls.Add("longDrordFlag", joRtn2[i]["long_drord_flag"]);
                        joOrls.Add("drordBegnDate", joRtn2[i]["drord_begn_date"]);
                        joOrls.Add("hilistName", joRtn2[i]["hilist_name"]);
                        joOrls.Add("currDrordFlag", joRtn2[i]["curr_drord_flag"]);
                        joOrls.Add("hosplistName", joRtn2[i]["hosplist_name"]);
                        joOrls.Add("lv1HospItemPric", joRtn2[i]["lv1_hosp_item_pric"]);
                        joOrls.Add("hilistMemo", joRtn2[i]["hilist_memo"]);
                        joOrls.Add("pric", joRtn2[i]["pric"]);
                        joOrls.Add("hosplistCode", joRtn2[i]["hosplist_code"]);
                        joOrls.Add("hilistCode", joRtn2[i]["hilist_code"]);
                        joOrls.Add("hilistDosform", joRtn2[i]["hilist_dosform"]);
                        joOrls.Add("hilistType", joRtn2[i]["hilist_type"]);
                        joOrls.Add("grpno", joRtn2[i]["grpno"]);
                        joOrls.Add("cnt", joRtn2[i]["cnt"]);
                        joOrls.Add("selfpayAmt", joRtn2[i]["selfpay_amt"]);
                        joOrls.Add("drordDeptCodg", joRtn2[i]["drord_dept_codg"]);
                        joOrls.Add("lv2HospItemPric", joRtn2[i]["lv2_hosp_item_pric"]);
                        joOrls.Add("drordStopDate", joRtn2[i]["drord_stop_date"]);
                        joOrls.Add("rxno", joRtn2[i]["rxno"]);
                        joOrls.Add("hosplistDosform", joRtn2[i]["hosplist_dosform"]);
                        joOrls.Add("rxId", joRtn2[i]["rx_id"]);
                        joOrls.Add("ownpayAmt", joRtn2[i]["ownpay_amt"]);
                        if (string.IsNullOrEmpty(fsi_order_dtos[i]["drord_dr_profttl"].ToString()))
                        {
                            joOrls.Add("drordDrProfttl", "234");
                        }
                        else
                        {
                            joOrls.Add("drordDrProfttl", joRtn2[i]["drord_dr_profttl"]);
                        }
                        joOrls.Add("hilistLv", joRtn2[i]["hilist_lv"]);
                        joOrls.Add("sumamt", joRtn2[i]["sumamt"]);
                        order3101.Add(joOrls);
                    }


                    //return JArray.FromObject(joRtn["data"]);
                    return order3101;
                }
            }
            
            catch (Exception ex)
            {
                MessageBox.Show("GetFsi__order_dtos:" + ex.Message);
                return null;
            }
        }
        #endregion
    }


}
